Weight

Enum Weight 

pub enum Weight<T>
where T: Zero<T> + Add<Output = T> + Sub<Output = T> + PartialEq + PartialOrd + Copy + Display,
{ Unit(T), Infinity, NaN, }
Generic implementation of weight with any units that implement std::ops::Add and std::ops::Sub. This type wraps the unit in a system with an infinity point and a “not a number” point used by the algorithms.

Implements WeightUnit and Zero.

Example

use core_cbc_casper::util::weight::Weight::{self, *};

assert_eq!(Unit(2), Unit(1) + Unit(1));
assert_eq!(Infinity, Unit(1) + Infinity);
assert_eq!(Weight::<u32>::NaN.to_string(), (Unit(1) + NaN).to_string());

Variants



Unit(T)



Infinity



NaN