#[repr(C)]pub struct Hash(pub [u8; 64]);Tuple Fields
0: [u8; 64]Implementations
Sourceimpl Hash
impl Hash
Sourcepub fn repeat_byte(byte: u8) -> Hash
pub fn repeat_byte(byte: u8) -> Hash
Returns a new fixed hash where all bits are set to the given byte.
Sourcepub fn as_bytes_mut(&mut self) -> &mut [u8] ⓘ
pub fn as_bytes_mut(&mut self) -> &mut [u8] ⓘ
Extracts a mutable byte slice containing the entire fixed hash.
Sourcepub fn as_fixed_bytes(&self) -> &[u8; 64]
pub fn as_fixed_bytes(&self) -> &[u8; 64]
Extracts a reference to the byte array containing the entire fixed hash.
Sourcepub fn as_fixed_bytes_mut(&mut self) -> &mut [u8; 64]
pub fn as_fixed_bytes_mut(&mut self) -> &mut [u8; 64]
Extracts a reference to the byte array containing the entire fixed hash.
Sourcepub fn to_fixed_bytes(self) -> [u8; 64]
pub fn to_fixed_bytes(self) -> [u8; 64]
Returns the inner bytes array.
Sourcepub fn as_mut_ptr(&mut self) -> *mut u8
pub fn as_mut_ptr(&mut self) -> *mut u8
Returns a mutable raw pointer to the value.
Sourcepub fn assign_from_slice(&mut self, src: &[u8])
pub fn assign_from_slice(&mut self, src: &[u8])
Sourcepub fn from_slice(src: &[u8]) -> Self
pub fn from_slice(src: &[u8]) -> Self